# Mr-distributions package
version 0.1

The package lets you install the gaussian and binomial distribution package

# files
binomialdistribution.py
gaussiandistribution.py
generaldistribution.py
license.txt
setup.cfg
setup.py
__init__.py

#installation
pip install